@@ -15,16 +15,16 @@ import os
 import argparse
 
 
-__version__ = "2.3.0"
+__version__ = "2.4.1"
 
-TAGS = dict(a='artist', b='album', c='composer', d='date',
-            g='genre', n='tracknumber', t='title')
+TAGS = {'a': 'artist', 'b': 'album', 'c': 'composer', 'd': 'date',
+        'g': 'genre', 'n': 'tracknumber', 't': 'title'}
 
 
 def parse_args(sys_args):  # pylint: disable=W0613
     """CLI arguments comprehension"""
     example_text = '''example:
-        $ rename-flac "%n - %t" "/media/Main/Musique/The Beatles"'''
+        $ rename-flac "%n - %t" "/media/Main/Musique/The Beatles" --sanitize-slash'''
     parser = argparse.ArgumentParser(prog='rename-flac',
                                  formatter_class=argparse.RawDescriptionHelpFormatter,
                                  description=__doc__,
@@ -33,6 +33,9 @@ def parse_args(sys_args):  # pylint: disable=W0613
                     help='filenaming scheme')
     parser.add_argument('directory', type=str,
                     help='path to the directory containing the album')
+    parser.add_argument('--sanitize-slash', metavar='CHAR', nargs='?', const='∕', default=None,
+                    help=('replace "/" in metadata with a filesystem-safe character, '
+                          'default: "∕" (Division Slash U+2215)'))
     parser.add_argument('--version', action='version', version='%(prog)s ' + __version__)
     parser.add_argument('--verbose', action='store_true',
                     help='run the program in verbose mode')
@@ -43,24 +46,23 @@ def scheme_processing(args):
     """Process the scheming arguments."""
     if not re.search("%[tn]", args.scheme):  # To have a unique filename
         raise ValueError("%t or %n has to be present in <scheme>")
-    scheme = re.sub('%%([%s])' % ''.join(TAGS.keys()),
-                    lambda m: '%%(%s)s' % TAGS[m.group(1)],
-                    args.scheme)
+    scheme = re.sub('%%([%s])' % ''.join(TAGS.keys()),  # pylint: disable=C0209
+                    lambda m: '%%(%s)s' % TAGS[m.group(1)], args.scheme)  # pylint: disable=C0209
     return scheme
 
 
 def fetch_metadata(filepath):
     """Fetch metadata and format it."""
-    mf_args = ["--show-tag=%s" % tag for tag in TAGS.values()]
-    tags = ["%s=" % tag for tag in TAGS.values()]
+    mf_args = ["--show-tag=%s" % tag for tag in TAGS.values()]  # pylint: disable=C0209
+    tags = ["%s=" % tag for tag in TAGS.values()]  # pylint: disable=C0209
     # make sure the keys exist. Prevents failure in case of incomplete metadata
     metadata = dict.fromkeys(list(TAGS.values()), '')
-    pipe = subprocess.Popen(["metaflac"] + mf_args + [filepath],
-                            stdout=subprocess.PIPE)
+    pipe = subprocess.Popen(["metaflac"] + mf_args + [filepath],  # pylint: disable=R1732
+                            stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+                            encoding='utf-8')
     output, error = pipe.communicate()
     if pipe.returncode:
-        raise IOError("metaflac failed: %s" % error)
-    output = output.decode('utf-8') # binary to string
+        raise OSError(f"metaflac failed: {error}")
     output = output.splitlines()
     for tag in tags:
         for item in output:
@@ -77,15 +79,25 @@ def fetch_metadata(filepath):
 def rename(scheme, dirname, filename, args):
     """Renames the files."""
     filepath = os.path.join(dirname, filename)
-    new_filename = scheme % fetch_metadata(filepath) + ".flac"
+    new_filename = scheme % fetch_metadata(filepath)
+    if '/' in new_filename:
+        if args.sanitize_slash is not None:
+            new_filename = new_filename.replace('/', args.sanitize_slash)
+        else:
+            sys.exit(f"Error: {filename} title contains /. Please rename it"
+                     "(or use the --sanitize-slash argument)")
+    new_filename += ".flac"
     if new_filename == filename:
         if args.verbose:
-            print('"%s" is already named correctly' % filename)
+            print(f"{filename} is already named correctly")
     else:
         new_filepath = os.path.join(dirname, new_filename)
-        os.rename(filepath, new_filepath)
+        if os.path.exists(new_filepath):
+            sys.exit(f"File {new_filepath} already exists. Rename aborted.")
+        else:
+            os.rename(filepath, new_filepath)
         if args.verbose:
-            print('"%s" --> "%s"' % (filename, new_filename))
+            print(f"{filename} --> {new_filename}")
 
 
 def main():
@@ -93,23 +105,15 @@ def main():
     args = parse_args(sys.argv[1:])
     scheme = scheme_processing(args)
     if not os.path.isdir(args.directory):
-        raise NotADirectoryError("%s is not a valid directory"
-                                 % args.directory)
+        raise NotADirectoryError(f"{args.directory} is not a valid directory")
     counter = 0
     for dirname, _, filenames in os.walk(args.directory, topdown=False):
         for filename in sorted(filenames):
             if filename.endswith('.flac'):
                 counter += 1
-                try:
-                    rename(scheme, dirname, filename, args)
-                except KeyboardInterrupt:
-                    raise
-                except OSError:
-                    sys.exit("Error: %s title contains /. Please rename it"
-                             % filename)
+                rename(scheme, dirname, filename, args)
     if counter < 1:
-        raise FileNotFoundError("No FLAC files found in %s"
-                                 % args.directory)
+        raise FileNotFoundError(f"No FLAC files found in {args.directory}")
 
 
 if __name__ == "__main__":
